@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import json
+from pagador.acesso.externo import FormatoDeEnvio
 from pagador.envio.requisicao import Enviar
 from pagador.envio.serializacao import Atributo
 from pagador.retorno.models import SituacaoPedido
@@ -16,7 +17,7 @@ class EnviarPedido(Enviar):
         self.processa_resposta = True
         self.url = "https://api.mercadolibre.com/checkout/preferences"
         self.grava_identificador = True
-        self.envio_por_querystring = False
+        self.formato_de_envio = FormatoDeEnvio.json
 
     def gerar_dados_de_envio(self):
         notification_url = MERCADOPAGO_PREFERENCE_NOTIFICATION_URL.format(self.pedido.conta_id)
